summaryrefslogtreecommitdiff
path: root/errors.go
diff options
context:
space:
mode:
Diffstat (limited to 'errors.go')
-rwxr-xr-xerrors.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/errors.go b/errors.go
index 52356549..7c91a92b 100755
--- a/errors.go
+++ b/errors.go
@@ -1,11 +1,11 @@
package roadrunner
// JobError is job level error (no WorkerProcess halt), wraps at top
// of error context
-type JobError []byte
+type ExecError []byte
// Error converts error context to string
-func (te JobError) Error() string {
+func (te ExecError) Error() string {
return string(te)
}
@@ -1,11 +1,11 @@
package roadrunner
-// JobError is job level error (no WorkerProcess halt), wraps at top
+// ExecError is job level error (no WorkerProcess halt), wraps at top
// of error context